@@ -19,6 +19,6 @@
 
 LIBDIR = r'/usr/local/lib'
 DATADIR = r'/usr/local/share'
-BUILDDIR = r'/pobj/gst-devtools-1.26.7/build-mips64'
-SRCDIR = r'/pobj/gst-devtools-1.26.7/gst-devtools-1.26.7'
+BUILDDIR = r'/usr/obj/ports/gst-devtools-1.26.8/build-sparc64'
+SRCDIR = r'/usr/obj/ports/gst-devtools-1.26.8/gst-devtools-1.26.8'
 GST_VALIDATE_TESTSUITE_VERSION = '1.26'
